CREATE TABLE IF NOT EXISTS `newsletter_email` ( 
`id_newsletter_email` int(11) NOT NULL AUTO_INCREMENT,
`email` varchar(255) CHARACTER SET utf8,
`date` DATETIME,
PRIMARY KEY (`id_newsletter_email`) 
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

CREATE TABLE IF NOT EXISTS `newsletter_message` ( 
`id_newsletter_message` int(11) NOT NULL AUTO_INCREMENT,
`subject` varchar(255) CHARACTER SET utf8,
`text` text,
`sended` tinyint(1),
PRIMARY KEY (`id_newsletter_message`) 
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

CREATE TABLE IF NOT EXISTS `newsletter_message_email_linker` (
  `id_newsletter_message_email_linker` int(11) NOT NULL AUTO_INCREMENT,
  `id_newsletter_message` int(11) NOT NULL,
  `id_newsletter_email` int(11) NOT NULL,
PRIMARY KEY (`id_newsletter_message_email_linker`) 
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;